# enable_gtkdoc: Toggle if gtk-doc files should be rebuilt.
#      0 = no
#      1 = yes
%define enable_gtkdoc 1

# enable_tests: Run test suite in build
#      0 = no
#      1 = yes
%define enable_tests 0

%{?_without_gtkdoc: %{expand: %%define enable_gtkdoc 0}}
%{?_without_tests: %{expand: %%define enable_tests 0}}

%{?_with_gtkdoc: %{expand: %%define enable_gtkdoc 1}}
%{?_with_tests: %{expand: %%define enable_tests 1}}


%define pkgname		gdk-pixbuf
%define api		2.0
%define binary_version	2.10.0
%define lib_major	0
%define gir_major	2.0

%define libname		%mklibname gdk_pixbuf %{api} %{lib_major}
%define develname	%mklibname -d gdk_pixbuf %{api}
%define girname		%mklibname gdk_pixbuf-gir %{gir_major}

%define url_ver %(echo %{version}|cut -d. -f1,2)

Summary:	Image loading and manipulation library for GTK+
Name:		%{pkgname}%{api}
Version:	2.42.2
Release:        %mkrel 1
License:	LGPLv2+
Group:		System/Libraries
Source0:	https://download.gnome.org/sources/%{pkgname}/%{url_ver}/%{pkgname}-%{version}.tar.xz
# https://gitlab.gnome.org/GNOME/gdk-pixbuf/merge_requests/49
URL:		http://www.gtk.org
Requires:	common-licenses
BuildRequires:	meson
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gmodule-no-export-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(jasper)
%if %enable_tests
BuildRequires:	x11-server-xvfb
%endif
%if %enable_gtkdoc
BuildRequires:	gtk-doc
BuildRequires:	sgml-tools
BuildRequires:	texinfo
%endif
# gw tests will fail without this
BuildRequires:	fonts-ttf-dejavu
BuildRequires:	pkgconfig(shared-mime-info)

%description
This package contains libraries used by GTK+ to load and handle
various image formats.

%package -n %{libname}
Summary:	Image loading and manipulation library for GTK+
Group:		System/Libraries
Provides:	libgdk_pixbuf%{api} = %{version}-%{release}
Requires:	%{name} >= %{version}-%{release}

%description -n %{libname}
This package contains libraries used by GTK+ to load and handle
various image formats.

%package -n %{develname}
Summary:	Development files for image handling library for GTK+
Group:		Development/GNOME and GTK+
Provides:	libgdk_pixbuf%{api}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Requires:	pkgconfig(libpng16)
Conflicts:	%{_lib}gdk_pixbuf-gir2.0 < 2.38.1-2

%description -n %{develname}
This package contains the development files needed to compile programs
that uses GTK+ image loading/manipulation library.

%package -n %{girname}
Summary:        GObject Introspection interface description for %{name}
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%prep
%setup -qn %{pkgname}-%{version}
%autopatch -p1

%build
%meson -Dinstalled_tests=false
%meson_build

%check
%if %enable_tests
xvfb-run %meson_test
%endif

%install
%meson_install

touch %{buildroot}%{_libdir}/%{pkgname}-%{api}/%{binary_version}/loaders.cache

# handle biarch packages
progs="gdk-pixbuf-query-loaders"
mkdir -p %{buildroot}%{_libdir}/%{pkgname}-%{api}/bin
for f in $progs; do
  mv -f %{buildroot}%{_bindir}/$f %{buildroot}%{_libdir}/%{pkgname}-%{api}/bin/
  cat > %{buildroot}%{_bindir}/$f << EOF
#!/bin/sh
lib=%{_lib}
case ":\$1:" in
:lib*:) lib="\$1"; shift 1;;
esac
exec %{_prefix}/\$lib/%{pkgname}-%{api}/bin/$f \${1+"\$@"}
EOF
  chmod +x %{buildroot}%{_bindir}/$f
done

#remove not packaged files
find %buildroot -name '*.la' -delete

%find_lang %{pkgname}

%transfiletriggerin -- %{_libdir}/gdk-pixbuf-%{api}/%{binary_version}/loaders
if [ -x %{_bindir}/gdk-pixbuf-query-loaders ]; then
  %{_bindir}/gdk-pixbuf-query-loaders --update-cache
fi

%transfiletriggerpostun -- %{_libdir}/gdk-pixbuf-%{api}/%{binary_version}/loaders
if [ -x %{_bindir}/gdk-pixbuf-query-loaders ]; then
  %{_bindir}/gdk-pixbuf-query-loaders --update-cache
fi

%files -f %{pkgname}.lang
%license COPYING
%{_bindir}/gdk-pixbuf-query-loaders
%{_bindir}/gdk-pixbuf-pixdata
%{_bindir}/gdk-pixbuf-thumbnailer
%{_datadir}/thumbnailers/
%{_mandir}/man1/gdk-pixbuf-query-loaders.1*

%files -n %{libname}
%{_libdir}/libgdk_pixbuf-%{api}.so.%{lib_major}{,.*}
%dir %{_libdir}/%{pkgname}-%{api}/
%dir %{_libdir}/%{pkgname}-%{api}/bin/
%dir %{_libdir}/%{pkgname}-%{api}/%{binary_version}/
%dir %{_libdir}/%{pkgname}-%{api}/%{binary_version}/loaders/
%{_libdir}/%{pkgname}-%{api}/%{binary_version}/loaders/*.so
%{_libdir}/%{pkgname}-%{api}/bin/gdk-pixbuf-query-loaders
%ghost %verify (not md5 mtime size) %{_libdir}/%pkgname-%{api}/%{binary_version}/loaders.cache

%files -n %{girname}
%{_libdir}/girepository-1.0/GdkPixbuf-%{gir_major}.typelib
%{_libdir}/girepository-1.0/GdkPixdata-%{gir_major}.typelib

%files -n %{develname}
#doc %%{_datadir}/gtk-doc/html/gdk-pixbuf
%{_bindir}/gdk-pixbuf-csource
%{_includedir}/%{pkgname}-%{api}/
%{_libdir}/libgdk_pixbuf*.so
%{_libdir}/pkgconfig/gdk-pixbuf*.pc
%{_datadir}/gir-1.0/GdkPixbuf-%{gir_major}.gir
%{_datadir}/gir-1.0/GdkPixdata-%{gir_major}.gir
%{_mandir}/man1/gdk-pixbuf-csource.1*


%changelog
* Tue Dec 08 2020 ovitters <ovitters> 2.42.2-1.mga8
+ Revision: 1654344
- new version 2.42.2

* Wed Nov 11 2020 tv <tv> 2.42.0-1.mga8
+ Revision: 1644448
- the gdk-pixbuf-xlib library has been split to a separate repository
+ ovitters <ovitters>
- new version 2.42.0

* Sun Feb 16 2020 umeabot <umeabot> 2.40.0-2.mga8
+ Revision: 1535038
- Mageia 8 Mass Rebuild

* Tue Oct 08 2019 ovitters <ovitters> 2.40.0-1.mga8
+ Revision: 1450647
- new version 2.40.0

* Mon Sep 09 2019 ovitters <ovitters> 2.38.2-1.mga8
+ Revision: 1438583
- new version 2.38.2
- dropped merged patch disable-deprecation-warnings-for-GTimeVal.patch

* Sat Aug 24 2019 wally <wally> 2.38.1-4.mga8
+ Revision: 1431748
- add upstream patch to disable deprecation warnings for GTimeVal

* Wed Apr 17 2019 umeabot <umeabot> 2.38.1-3.mga7
+ Revision: 1392195
- Rebuild with meson 0.50.1

* Tue Apr 16 2019 wally <wally> 2.38.1-2.mga7
+ Revision: 1391687
- update gdk-pixbuf loaders cache with transfiletriggers
- move all .gir files to devel pkg
- drop old obsoletes/conflicts and unneeded requires

* Thu Feb 28 2019 ovitters <ovitters> 2.38.1-1.mga7
+ Revision: 1370514
- new version 2.38.1

* Mon Sep 03 2018 tv <tv> 2.38.0-2.mga7
+ Revision: 1256794
- do not install tests
- adjust filelist
- switch to meson
+ ovitters <ovitters>
- new version 2.38.0
- new version 2.37.92

* Mon Apr 16 2018 daviddavid <daviddavid> 2.36.12-2.mga7
+ Revision: 1219276
- rebuild for new jasper 2.0.14

* Sun Apr 08 2018 ovitters <ovitters> 2.36.12-1.mga7
+ Revision: 1216066
- new version 2.36.12

* Mon Oct 02 2017 ovitters <ovitters> 2.36.11-1.mga7
+ Revision: 1162808
- new version 2.36.11

* Mon Sep 11 2017 ovitters <ovitters> 2.36.10-1.mga7
+ Revision: 1152817
- new version 2.36.10
- new version 2.36.9
- new version 2.36.8

* Tue Jul 18 2017 ovitters <ovitters> 2.36.7-1.mga7
+ Revision: 1124801
- new version 2.36.7

* Sun Mar 26 2017 ovitters <ovitters> 2.36.6-1.mga6
+ Revision: 1094865
- new version 2.36.6

* Mon Feb 13 2017 ovitters <ovitters> 2.36.5-1.mga6
+ Revision: 1085982
- new version 2.36.5

* Mon Jan 16 2017 ovitters <ovitters> 2.36.4-1.mga6
+ Revision: 1082079
- new version 2.36.4

* Wed Jan 04 2017 ovitters <ovitters> 2.36.3-1.mga6
+ Revision: 1080110
- new version 2.36.3

* Tue Dec 20 2016 ovitters <ovitters> 2.36.2-1.mga6
+ Revision: 1076202
- new version 2.36.2

* Tue Dec 13 2016 ovitters <ovitters> 2.36.1-1.mga6
+ Revision: 1074725
- new version 2.36.1
+ tv <tv>
- package COPYING (using %%license)
- stop packaging empty README

* Mon Sep 26 2016 tv <tv> 2.36.0-2.mga6
+ Revision: 1056770
- rebuild with fixed rpm-mageia-setup for missing generating typelib() requires (mga#19454)

* Mon Sep 19 2016 ovitters <ovitters> 2.36.0-1.mga6
+ Revision: 1054307
- new version 2.36.0

* Sun Sep 18 2016 ovitters <ovitters> 2.35.4-1.mga6
+ Revision: 1053885
- new version 2.35.4
- dropped merged patch 1

* Fri Sep 09 2016 luigiwalser <luigiwalser> 2.34.0-2.mga6
+ Revision: 1051056
- rediff upstream patch to fix CVE-2016-6352

* Thu Mar 24 2016 ovitters <ovitters> 2.34.0-1.mga6
+ Revision: 995217
- new version 2.34.0

* Mon Dec 14 2015 ovitters <ovitters> 2.33.2-1.mga6
+ Revision: 910382
- new version 2.33.2

* Mon Nov 23 2015 ovitters <ovitters> 2.33.1-1.mga6
+ Revision: 904994
- new version 2.33.1

* Mon Nov 09 2015 ovitters <ovitters> 2.32.2-1.mga6
+ Revision: 900093
- new version 2.32.2

* Thu Oct 01 2015 luigiwalser <luigiwalser> 2.32.1-1.mga6
+ Revision: 885531
- 2.32.1

* Wed Sep 23 2015 fwang <fwang> 2.32.0-1.mga6
+ Revision: 882333
- 2.32.0

* Tue Sep 01 2015 ovitters <ovitters> 2.31.7-1.mga6
+ Revision: 871929
- new version 2.31.7

* Wed Aug 19 2015 ovitters <ovitters> 2.31.6-1.mga6
+ Revision: 865822
- new version 2.31.6

* Mon Jul 20 2015 ovitters <ovitters> 2.31.5-1.mga6
+ Revision: 855801
- new version 2.31.5
- dropped merged patch 1

* Mon Jul 13 2015 ovitters <ovitters> 2.31.4-3.mga6
+ Revision: 853688
- add upstream patch to fix integer overflow (bgo#752297 mga#16367)

* Sun Jun 28 2015 wally <wally> 2.31.4-2.mga6
+ Revision: 846643
- add requires for gir pkg to devel pkg

* Sat Jun 20 2015 ovitters <ovitters> 2.31.4-1.mga6
+ Revision: 836346
- new version 2.31.4
- dropped merged patch 1

* Sun Apr 05 2015 tv <tv> 2.31.2-2.mga5
+ Revision: 819720
- patch 0: fix regression breaking taking screenshots with virt-manager (mga#15628)

* Wed Dec 24 2014 ovitters <ovitters> 2.31.2-1.mga5
+ Revision: 805420
- new version 2.31.2

* Wed Oct 15 2014 umeabot <umeabot> 2.31.1-4.mga5
+ Revision: 740245
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 tv <tv> 2.31.1-3.mga5
+ Revision: 731138
- rebuild so that it picks typelib() requires

* Tue Sep 16 2014 umeabot <umeabot> 2.31.1-2.mga5
+ Revision: 679460
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 ovitters <ovitters> 2.31.1-1.mga5
+ Revision: 670720
- new version 2.31.1

* Mon Jul 21 2014 ovitters <ovitters> 2.31.0-1.mga5
+ Revision: 655176
- new version 2.31.0

* Wed May 28 2014 ovitters <ovitters> 2.30.8-1.mga5
+ Revision: 627088
- new version 2.30.8

* Tue Mar 25 2014 ovitters <ovitters> 2.30.7-1.mga5
+ Revision: 608525
- new version 2.30.7

* Mon Mar 03 2014 ovitters <ovitters> 2.30.6-1.mga5
+ Revision: 598905
- new version 2.30.6

* Tue Feb 18 2014 ovitters <ovitters> 2.30.5-1.mga5
+ Revision: 594099
- new version 2.30.5

* Tue Feb 04 2014 ovitters <ovitters> 2.30.4-1.mga5
+ Revision: 582473
- new version 2.30.4

* Mon Nov 11 2013 ovitters <ovitters> 2.30.1-1.mga4
+ Revision: 550560
- new version 2.30.1

* Sat Oct 19 2013 umeabot <umeabot> 2.30.0-2.mga4
+ Revision: 536416
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 ovitters <ovitters> 2.30.0-1.mga4
+ Revision: 484235
- new version 2.30.0

* Tue Jul 30 2013 ovitters <ovitters> 2.29.3-1.mga4
+ Revision: 460771
- new version 2.29.3

* Mon Jun 24 2013 ovitters <ovitters> 2.29.2-1.mga4
+ Revision: 446257
- new version 2.29.2

* Sat Jun 08 2013 ovitters <ovitters> 2.28.2-1.mga4
+ Revision: 440373
- new version 2.28.2

* Tue Jun 04 2013 fwang <fwang> 2.28.1-5.mga4
+ Revision: 436902
- merge libpng loader into mainlib package, as we only provide single flavour now

* Mon Jun 03 2013 tv <tv> 2.28.1-4.mga4
+ Revision: 436299
- fix upgrade

* Sun Jun 02 2013 fwang <fwang> 2.28.1-3.mga4
+ Revision: 434597
- fix pkgname
- rebuild for new libpng

* Thu May 23 2013 tv <tv> 2.28.1-1.mga4
+ Revision: 425506
- new release

* Fri Jan 11 2013 umeabot <umeabot> 2.26.5-2.mga3
+ Revision: 351144
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 11 2012 fwang <fwang> 2.26.5-1.mga3
+ Revision: 316986
- new version 2.26.5

* Tue Sep 18 2012 ovitters <ovitters> 2.26.4-1.mga3
+ Revision: 295701
- new version 2.26.4

* Mon Aug 20 2012 ovitters <ovitters> 2.26.3-1.mga3
+ Revision: 282691
- new version 2.26.3

* Mon Aug 06 2012 ovitters <ovitters> 2.26.2-1.mga3
+ Revision: 279406
- new version 2.26.2

* Thu Jun 07 2012 tv <tv> 2.26.1-2.mga3
+ Revision: 256702
- use %%posttrans instead of %%post (mga#5464)

* Sat Apr 14 2012 ovitters <ovitters> 2.26.1-1.mga2
+ Revision: 230801
- new version 2.26.1

* Tue Mar 20 2012 ovitters <ovitters> 2.26.0-1.mga2
+ Revision: 225078
- new version 2.26.0

* Sun Feb 05 2012 fwang <fwang> 2.25.2-1.mga2
+ Revision: 204552
- update file list
- new version 2.25.2

* Mon Jan 23 2012 dmorgan <dmorgan> 2.25.0-4.mga2
+ Revision: 200185
- Fix package ownage

* Thu Jan 05 2012 tmb <tmb> 2.25.0-3.mga2
+ Revision: 190810
- make sure gdk-pixbuf-query-loaders is available when loaders-png package is installed

* Thu Dec 22 2011 fwang <fwang> 2.25.0-2.mga2
+ Revision: 186104
- rebuild for new libtiff

* Sat Dec 17 2011 fwang <fwang> 2.25.0-1.mga2
+ Revision: 183091
- build x11 support
- fix tarball
- new version 2.25.0

* Sat Nov 12 2011 tmb <tmb> 2.24.0-7.mga2
+ Revision: 167002
- require gdk-pixbuf2.0 in pre as gdk-pixbuf-query-loaders is called during install

* Mon Sep 26 2011 fwang <fwang> 2.24.0-6.mga2
+ Revision: 147934
- requires png pkconfig for private requires

* Fri Sep 23 2011 fwang <fwang> 2.24.0-5.mga2
+ Revision: 146935
- add scriptlet requires

* Fri Sep 23 2011 fwang <fwang> 2.24.0-4.mga2
+ Revision: 146912
- split out png pixbuf loader, for upcoming lsb compatible png1.2 loader

* Sat Sep 10 2011 fwang <fwang> 2.24.0-3.mga2
+ Revision: 142125
- drop all .la files

* Sat Sep 10 2011 fwang <fwang> 2.24.0-2.mga2
+ Revision: 142085
- rebuild for new libpng
- drop old style invalid req
- new version 2.24.0

* Fri Jul 15 2011 cjw <cjw> 2.23.5-5.mga2
+ Revision: 124437
- fix gobject introspection dependencies:
  o drop library -> typelib package dependency
  o move conflicts on gir-repository from library to typelib package
  o use obsoletes instead of conflicts for typelib package name change

* Thu Jul 07 2011 wally <wally> 2.23.5-4.mga2
+ Revision: 119850
- fix gir package name

* Thu Jul 07 2011 cjw <cjw> 2.23.5-3.mga2
+ Revision: 119561
- rebuild for automatic typelib provides

* Tue Jul 05 2011 dmorgan <dmorgan> 2.23.5-2.mga2
+ Revision: 118870
- Make the lib package requires the gir one

* Sun Jul 03 2011 wally <wally> 2.23.5-1.mga2
+ Revision: 117753
- new version 2.23.5
- create a subpackage for gir .typelib
- clean .spec a bit

* Thu Jun 09 2011 dmorgan <dmorgan> 2.23.3-1.mga2
+ Revision: 102739
- New version 2.23.3

* Mon Jan 24 2011 erwan <erwan> 2.22.1-3.mga1
+ Revision: 37901
- Rebuild

* Wed Jan 12 2011 tmb <tmb> 2.22.1-2.mga1
+ Revision: 7679
- imported package gdk-pixbuf2.0

* Wed Jan 12 2011 dmorgan <dmorgan> 2.22.1-1.mga1
+ Revision: 7103
- imported package gdk-pixbuf2.0

